@@ -1,7 +1,8 @@
 # -*- coding: utf-8 -*-
 
-"""
-    This module is used to deploy a whole django webapp on a remote/vagrant machine :
+""" This module is used to deploy a whole django webapp using chaussette/circus nginx on a remote/vagrant machine.
+
+This module shoud be imported in a fabfile to deploy an application using pydiploy.
 
 """
 
@@ -16,8 +17,8 @@ def application_packages(update=False):
     """ Installs all packages for django webapp """
     fabtools.require.deb.packages(['gettext'], update=update)
     # TODO contextual installation of ldap packages & postgres packages !!!
-    fabric.api.execute(pydiploy.require.database.ldap_pkg, use_sudo=True)
-    fabric.api.execute(pydiploy.require.database.postgres_pkg)
+    fabric.api.execute(pydiploy.require.databases.ldap.ldap_pkg, use_sudo=True)
+    fabric.api.execute(pydiploy.require.databases.postgres.postgres_pkg)
     if env.remote_python_version >= 3:
         fabric.api.execute(pydiploy.require.system.check_python3_install,
                            version='python%s' % env.remote_python_version)
@@ -32,7 +33,7 @@ def application_packages(update=False):
 
 def pre_install_backend(commands='/usr/bin/rsync'):
     """ Installs requirements for circus & virtualenv env """
-    fabric.api.execute(pydiploy.require.system.django_user, commands=commands)
+    fabric.api.execute(pydiploy.require.system.add_user, commands=commands)
     fabric.api.execute(pydiploy.require.system.set_locale)
     fabric.api.execute(pydiploy.require.system.set_timezone)
     fabric.api.execute(pydiploy.require.system.update_pkg_index)
@@ -49,10 +50,12 @@ def pre_install_frontend():
     fabric.api.execute(pydiploy.require.nginx.nginx_pkg)
 
 
-def deploy(upgrade_pkg=False, **kwargs):
+def deploy_backend(upgrade_pkg=False, **kwargs):
     """ Deploys django webapp with required tag """
     fabric.api.execute(pydiploy.require.releases_manager.setup)
     fabric.api.execute(pydiploy.require.releases_manager.deploy_code)
+    fabric.api.execute(pydiploy.require.django.utils.deploy_manage_file)
+    fabric.api.execute(pydiploy.require.django.utils.deploy_wsgi_file)
     fabric.api.execute(
         pydiploy.require.python.utils.application_dependencies, upgrade_pkg)
     fabric.api.execute(pydiploy.require.django.utils.app_settings, **kwargs)
@@ -62,6 +65,11 @@ def deploy(upgrade_pkg=False, **kwargs):
     fabric.api.execute(pydiploy.require.releases_manager.cleanup)
 
 
+def deploy_frontend():
+    """ Synchronises static files after deploy """
+    fabric.api.execute(pydiploy.require.nginx.web_static_files)
+
+
 def rollback():
     """ Rolls back django webapp """
     fabric.api.execute(pydiploy.require.releases_manager.rollback_code)
@@ -69,13 +77,12 @@ def rollback():
 
 
 def post_install_backend():
-    """ Post installation of webapp"""
+    """ Post-installation of webapp"""
     fabric.api.execute(pydiploy.require.circus.app_circus_conf)
     fabric.api.execute(pydiploy.require.circus.app_reload)
 
 
 def post_install_frontend():
-    fabric.api.execute(pydiploy.require.nginx.web_static_files)
     fabric.api.execute(pydiploy.require.nginx.web_configuration)
     fabric.api.execute(pydiploy.require.nginx.nginx_restart)
 
@@ -86,10 +93,54 @@ def dump_database():
 
 
 def reload_frontend():
-    """ Reload frontend """
+    """ Reloads frontend """
     fabric.api.execute(pydiploy.require.nginx.nginx_reload)
 
 
 def reload_backend():
-    """ Reload backend """
+    """ Reloads backend """
     fabric.api.execute(pydiploy.require.circus.app_reload)
+
+
+def set_app_down():
+    """ Sets app in maintenance mode """
+    fabric.api.execute(pydiploy.require.nginx.down_site_config)
+    fabric.api.execute(pydiploy.require.nginx.set_website_down)
+
+
+def set_app_up():
+    """ Sets app in maintenance mode """
+    fabric.api.execute(pydiploy.require.nginx.set_website_up)
+
+
+def custom_manage_command(cmd):
+    """ Passes custom commandes to manage.py """
+    fabric.api.execute(pydiploy.require.django.command.django_custom_cmd, cmd)
+
+
+def install_postgres_server(user=None,dbname=None,password=None):
+    """ Install postgres server & add user for postgres
+
+        if no parameters are provided using (if exists) ::
+
+            default_db_user
+            default_db_name
+            default_db_password
+
+    """
+
+    if not (user and dbname and password):
+        if all([e in env.keys() for e in ('default_db_user', 'default_db_name', 'default_db_password')]):
+            user = env.default_db_user
+            dbname = env.default_db_name
+            password = env.default_db_password
+        else:
+            fabric.api.abort('Please provide user,dbname,password parameters for postgres.')
+
+    fabric.api.execute(pydiploy.require.databases.postgres.install_postgres_server)
+    fabric.api.execute(pydiploy.require.databases.postgres.add_postgres_user,user,password=password)
+    fabric.api.execute(pydiploy.require.databases.postgres.add_postgres_database,dbname,owner=user,locale=env.locale)
+
+def install_oracle_client():
+    """ Installs oracle client """
+    fabric.api.execute(pydiploy.require.databases.oracle.install_oracle_client)
