@@ -1,4 +1,4 @@
 # -*- coding: utf-8 -*-
 
-from pydiploy.require import (circus, database, django, git, nginx, python,
+from pydiploy.require import (circus, databases, django, git, nginx, python,
                               releases_manager, system)
