@@ -1,10 +1,16 @@
 # -*- coding: utf-8 -*-
 
 """
-Circus
-======
 
-.. circus: http://circus.readthedocs.org
+Methods to install circus package
+
+
+
+.. seealso::
+
+    `circus documentation <http://circus.readthedocs.org>`_
+      Circus official documentation.
+
 """
 
 import os
@@ -16,6 +22,7 @@ from fabric.api import env
 
 def circus_pkg(update=False):
     """ Installs packages relatives to circus """
+
     # install ubuntu ppa for libzmq-dev if ubuntu <= 10.04
     if fabtools.system.distrib_id() == 'Ubuntu' and fabtools.system.distrib_release() == '10.04':
         fabtools.require.deb.packages(['python-software-properties'],
@@ -55,7 +62,9 @@ def circus_pkg(update=False):
 
 
 def app_circus_conf():
-    """ Sets circus application's configuration using templates in templates dir """
+    """
+    Sets circus app's configuration using templates in templates dir
+    """
 
     fabtools.files.upload_template('app.ini.tpl',
                                    os.path.join(env.remote_home, '.circus.d',
@@ -71,8 +80,11 @@ def app_circus_conf():
 
 
 def upstart():
-    """ Sets script to start circus at boot using templates in templates dir """
+    """
+    Sets script to start circus at boot using templates in templates dir
+    """
 
+    # TODO: implement as systemd service !!!
     # init files to declare circus as an upstart daemon
     fabtools.files.upload_template('upstart.conf.tpl',
                                    '/etc/init/circus.conf',
@@ -87,7 +99,8 @@ def upstart():
 
 
 def app_reload():
-    """ Starts/Restarts app using circus """
+    """ Starts/restarts app using circus """
+
     if not 'running' in fabric.api.sudo('status circus'):
         fabric.api.sudo('start circus')
     else:
