@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-""" Utilities for django settings. """
+""" Utilities for django (settings...) """
 
 import os
 import random
@@ -13,7 +13,8 @@ from fabric.api import env
 
 
 def generate_secret_key():
-    """ Generate the django's secret key. """
+    """ Generates the django's secret key. """
+
     letters = string.ascii_letters + string.punctuation.replace('\'', '')
     random_letters = map(lambda i: random.SystemRandom().choice(letters),
                          range(50))
@@ -22,7 +23,8 @@ def generate_secret_key():
 
 
 def extract_settings():
-    """ Extract settings from django settings files. """
+    """ Extracts settings from django settings files. """
+
     # get the remote file
     fabric.api.get(env.previous_settings_file, local_path=env.local_tmp_dir)
     settings_file = os.path.join(env.local_tmp_dir, '%s.py' % env.goal)
@@ -52,7 +54,7 @@ def extract_settings():
 
 
 def app_settings(**kwargs):
-    """ Manage django settings file """
+    """ Manages django settings file """
 
     settings_present = fabtools.files.is_file(path=env.previous_settings_file,
                                               use_sudo=True)
@@ -85,3 +87,33 @@ def app_settings(**kwargs):
                                    mode='644',
                                    chown=True,
                                    use_jinja=True)
+
+
+def deploy_manage_file():
+    """ uploads manage.py template on remote """
+
+    fabtools.files.upload_template('manage.py',
+                                   os.path.join(
+                                       env.remote_current_release, 'manage.py'),
+                                   template_dir=env.local_tmp_root_app,
+                                   context=env,
+                                   use_sudo=True,
+                                   user=env.remote_owner,
+                                   chown=True,
+                                   mode='744',
+                                   use_jinja=True)
+
+
+def deploy_wsgi_file():
+    """ Uploads wsgi.py template on remote """
+
+    fabtools.files.upload_template('wsgi.py',
+                                   os.path.join(
+                                       env.remote_base_package_dir, 'wsgi.py'),
+                                   template_dir=env.local_tmp_root_app_package,
+                                   context=env,
+                                   use_sudo=True,
+                                   user=env.remote_owner,
+                                   chown=True,
+                                   mode='644',
+                                   use_jinja=True)
