@@ -1,4 +1,7 @@
 # -*- coding: utf-8 -*-
+
+""" Utilities module for python """
+
 import os
 
 import fabric
@@ -7,9 +10,8 @@ from fabric.api import env
 
 
 def python_pkg(update=False):
-    """
-    Installs python packages and pip
-    """
+    """ Installs python packages and pip """
+
     fabtools.require.deb.packages([
         '%s' % 'python-dev' if env.remote_python_version < 3 else 'python%s-dev' % env.remote_python_version,
         'python-pip'
@@ -18,9 +20,8 @@ def python_pkg(update=False):
 
 
 def application_dependencies(upgrade_pkg, staging=True):
-    """
-    Installs application dependencies with requirements.txt files
-    """
+    """ Installs application dependencies with requirements.txt files """
+
     with fabtools.python.virtualenv(env.remote_virtualenv_dir):
         with fabric.api.cd(env.remote_current_path):
             requirements_file = os.path.join('requirements',
